@@ -146,14 +146,20 @@ class Browser(contextlib.AbstractContextManager):
     url: str
     start_browser: Optional[webdriver.WebDriver] = None
 
+    def open(self) -> None:
+        self.driver = self.start_browser()
+        self.driver.get(self.url)
+        return BrowserContext(self.url, self.driver)
+
+    def close(self) -> None:
+        self.driver.close()
+
     def __post_init__(self) -> None:
         if self.start_browser is None:
             self.start_browser = getattr(webdriver, get_browser())
 
     def __enter__(self) -> BrowserContext:
-        self.driver = self.start_browser()
-        self.driver.get(self.url)
-        return BrowserContext(self.url, self.driver)
+        return self.open()
 
     def __exit__(self, exc_type, exc_value, traceback):
-        self.driver.close()
+        self.close()
